#line 2 "align/phylipsl.c"

#line 4 "align/phylipsl.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer phylips_create_buffer
#define yy_delete_buffer phylips_delete_buffer
#define yy_flex_debug phylips_flex_debug
#define yy_init_buffer phylips_init_buffer
#define yy_flush_buffer phylips_flush_buffer
#define yy_load_buffer_state phylips_load_buffer_state
#define yy_switch_to_buffer phylips_switch_to_buffer
#define yyin phylipsin
#define yyleng phylipsleng
#define yylex phylipslex
#define yylineno phylipslineno
#define yyout phylipsout
#define yyrestart phylipsrestart
#define yytext phylipstext
#define yywrap phylipswrap
#define yyalloc phylipsalloc
#define yyrealloc phylipsrealloc
#define yyfree phylipsfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 35
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#ifdef _LIBC
#include "namespace.h"
#endif
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/*	$NetBSD: flexint.h,v 1.1.1.1 2009/10/26 00:26:19 christos Exp $	*/

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;
#endif /* ! C99 */

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE phylipsrestart(phylipsin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

extern int phylipsleng;

extern FILE *phylipsin, *phylipsout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up phylipstext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up phylipstext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via phylipsrestart()), so that the user can continue scanning by
	 * just pointing phylipsin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when phylipstext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int phylipsleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow phylipswrap()'s to do buffer switches
 * instead of setting up a fresh phylipsin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void phylipsrestart (FILE *input_file  );
void phylips_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE phylips_create_buffer (FILE *file,int size  );
void phylips_delete_buffer (YY_BUFFER_STATE b  );
void phylips_flush_buffer (YY_BUFFER_STATE b  );
void phylipspush_buffer_state (YY_BUFFER_STATE new_buffer  );
void phylipspop_buffer_state (void );

static void phylipsensure_buffer_stack (void );
static void phylips_load_buffer_state (void );
static void phylips_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER phylips_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE phylips_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE phylips_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE phylips_scan_bytes (yyconst char *bytes,int len  );

void *phylipsalloc (yy_size_t  );
void *phylipsrealloc (void *,yy_size_t  );
void phylipsfree (void *  );

#define yy_new_buffer phylips_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        phylipsensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            phylips_create_buffer(phylipsin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        phylipsensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            phylips_create_buffer(phylipsin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define phylipswrap(n) (/*CONSTCOND*/1)
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *phylipsin = (FILE *) 0, *phylipsout = (FILE *) 0;

typedef int yy_state_type;

extern int phylipslineno;

int phylipslineno = 1;

extern char *phylipstext;
#define yytext_ptr phylipstext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
#if defined(__GNUC__) && __GNUC__ >= 3
__attribute__((__noreturn__))
#endif
static void yy_fatal_error (yyconst char msg[]  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up phylipstext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	phylipsleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 21
#define YY_END_OF_BUFFER 22
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_acclist[117] =
    {   0,
    16386,   22,   20,   21,   19,   21,    1,   19,   21,   20,
       21,16386,   20,   21,    8,   21,    4,    8,   21,    7,
       21,    4,    8,   21,    3,    8,   21,   18,   21,   17,
       21,16400,   12,   18,   21,   11,   18,   21,   11,   18,
       21,   18,   21,   13,   17,   21,16400,   12,   18,   21,
       11,   18,   21,   11,   18,   21,    1,16386,    4,    5,
        5,    6,    4,    3,16398,16400,   11,   11,   11,   11,
     8194,    6,16398,16400,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,

       11,   11,   11,   11,   10,    9,   10,   10,   11,   10,
       11, 8208,   15, 8208, 8206, 8208
    } ;

static yyconst flex_int16_t yy_accept[129] =
    {   0,
        1,    1,    2,    2,    2,    2,    2,    3,    5,    7,
       10,   13,   15,   17,   20,   22,   25,   28,   30,   33,
       36,   39,   42,   44,   48,   51,   54,   57,   58,   59,
       59,   59,   60,   61,   63,   64,   64,   65,   65,   67,
       67,   68,   69,   69,   69,   70,   71,   72,   73,   73,
       73,   75,   75,   75,   76,   77,   77,   77,   78,   79,
       79,   79,   79,   80,   81,   81,   81,   82,   83,   83,
       83,   83,   84,   85,   85,   85,   86,   87,   87,   87,
       87,   88,   89,   89,   89,   90,   91,   91,   91,   91,
       92,   93,   93,   93,   94,   95,   95,   95,   95,   96,

       97,   97,   97,   98,   99,   99,   99,   99,  100,  101,
      101,  101,  102,  103,  103,  103,  103,  104,  105,  106,
      108,  110,  112,  113,  113,  115,  117,  117
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    4,    1,    1,    1,    1,    1,    1,    1,    5,
        5,    6,    1,    5,    7,    8,    1,    9,    9,    9,
        9,    9,    9,    9,    9,    9,    9,    5,    5,    1,
        1,    1,   10,    1,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
        5,    1,    5,    1,    1,    1,   11,   11,   11,   11,

       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,   11,   11,   11,   11,   11,   11,   11,   11,
       11,   11,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[12] =
    {   0,
        1,    2,    3,    2,    4,    1,    1,    1,    5,    1,
        1
    } ;

static yyconst flex_int16_t yy_base[151] =
    {   0,
      121,    0,    8,   16,   25,   36,  122,  344,  344,  344,
       45,  108,  344,  104,  344,   53,   96,  344,   62,  344,
       61,    0,    0,   70,   96,   74,    0,  344,    0,   84,
       83,   88,  344,  344,    0,   83,   81,    0,   92,   85,
       91,    0,    0,   84,  102,    0,   70,  344,    0,    0,
        0,   73,   66,  108,    0,    0,   59,  119,    0,    0,
       58,   57,  125,    0,    0,   56,  136,    0,    0,   55,
       54,  142,    0,    0,   49,  153,    0,    0,   48,   47,
      159,    0,    0,   46,  170,    0,    0,   20,   19,  176,
        0,    0,   18,  187,    0,    0,   17,   12,  193,    0,

        0,   11,  204,    0,    0,   10,    9,  210,    0,    0,
        4,  221,    0,    0,    3,    2,  344,  344,  344,  344,
      344,  344,  344,    1,  344,  344,  344,  232,  237,  241,
      245,  248,  253,  258,  263,  268,  273,  278,  283,  288,
      293,  298,  303,  308,  313,  318,  323,  328,  333,  338
    } ;

static yyconst flex_int16_t yy_def[151] =
    {   0,
      128,  128,  129,  129,  127,  127,  127,  127,  127,  127,
      127,  130,  127,  131,  127,  127,  127,  127,  132,  127,
      127,   21,  133,  132,  133,  127,   26,  127,   11,  130,
      130,  131,  127,  127,   16,  127,  127,  134,  132,  134,
      127,   41,  135,  135,  127,   45,  127,  127,   36,  136,
       39,  134,  136,  127,   54,  137,  137,  127,   58,  138,
      136,  138,  127,   63,  139,  139,  127,   67,  140,  138,
      140,  127,   72,  141,  141,  127,   76,  142,  140,  142,
      127,   81,  143,  143,  127,   85,  144,  142,  144,  127,
       90,  145,  145,  127,   94,  146,  144,  146,  127,   99,

      147,  147,  127,  103,  148,  146,  148,  127,  108,  149,
      149,  127,  112,  150,  148,  150,  127,  127,  127,  127,
      127,  127,  127,  150,  127,  127,    0,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127,  127,  127,  127,  127,  127
    } ;

static yyconst flex_int16_t yy_nxt[356] =
    {   0,
      127,  127,   10,   11,  126,  125,  124,  120,   12,   14,
       15,   16,  116,  115,  111,  107,   17,   14,   15,   16,
      106,  102,   98,   97,   17,   18,   18,   19,   20,   18,
       21,   22,   22,   18,   21,   21,   23,   23,   24,   25,
       18,   26,   27,   27,   23,   26,   26,   28,   29,   93,
       89,   88,   84,   30,   32,   34,   35,   80,   79,   75,
       71,   70,   66,   36,   39,   40,   41,   42,   42,   62,
       41,   41,   39,   40,   43,   43,   61,   43,   47,   45,
       46,   46,   43,   45,   45,   48,   49,   57,   53,   37,
       33,   47,   30,   36,   51,   52,   54,   55,   55,   44,

       54,   54,   56,   56,   37,   56,   33,   58,   59,   59,
       56,   58,   58,   63,   64,   64,   30,   63,   63,   65,
       65,  127,   65,    9,   67,   68,   68,   65,   67,   67,
       72,   73,   73,  127,   72,   72,   74,   74,  127,   74,
      127,   76,   77,   77,   74,   76,   76,   81,   82,   82,
      127,   81,   81,   83,   83,  127,   83,  127,   85,   86,
       86,   83,   85,   85,   90,   91,   91,  127,   90,   90,
       92,   92,  127,   92,  127,   94,   95,   95,   92,   94,
       94,   99,  100,  100,  127,   99,   99,  101,  101,  127,
      101,  127,  103,  104,  104,  101,  103,  103,  108,  109,

      109,  127,  108,  108,  110,  110,  127,  110,  127,  112,
      113,  113,  110,  112,  112,  117,  118,  118,  127,  117,
      117,  119,  119,  127,  119,  127,  121,  122,  122,  119,
      121,  121,    8,    8,    8,    8,    8,   13,   13,   13,
       13,   13,   31,  127,  127,   31,   32,   32,   38,   38,
       38,  127,   38,   43,   43,  127,  127,   43,   50,   50,
      127,  127,   50,   56,   56,  127,  127,   56,   60,   60,
      127,  127,   60,   65,   65,  127,  127,   65,   69,   69,
      127,  127,   69,   74,   74,  127,  127,   74,   78,   78,
      127,  127,   78,   83,   83,  127,  127,   83,   87,   87,

      127,  127,   87,   92,   92,  127,  127,   92,   96,   96,
      127,  127,   96,  101,  101,  127,  127,  101,  105,  105,
      127,  127,  105,  110,  110,  127,  127,  110,  114,  114,
      127,  127,  114,  119,  119,  127,  127,  119,  123,  123,
      127,  127,  123,    7,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127
    } ;

static yyconst flex_int16_t yy_chk[356] =
    {   0,
        0,    0,    2,    2,  124,  116,  115,  111,    2,    3,
        3,    3,  107,  106,  102,   98,    3,    4,    4,    4,
       97,   93,   89,   88,    4,    5,    5,    5,    5,    5,
        5,    5,    5,    5,    5,    5,    6,    6,    6,    6,
        6,    6,    6,    6,    6,    6,    6,   11,   11,   84,
       80,   79,   75,   11,   16,   16,   16,   71,   70,   66,
       62,   61,   57,   16,   19,   19,   21,   21,   21,   53,
       21,   21,   24,   24,   26,   26,   52,   26,   47,   26,
       26,   26,   26,   26,   26,   36,   36,   44,   40,   37,
       32,   31,   30,   36,   39,   39,   41,   41,   41,   25,

       41,   41,   45,   45,   17,   45,   14,   45,   45,   45,
       45,   45,   45,   54,   54,   54,   12,   54,   54,   58,
       58,    7,   58,    1,   58,   58,   58,   58,   58,   58,
       63,   63,   63,    0,   63,   63,   67,   67,    0,   67,
        0,   67,   67,   67,   67,   67,   67,   72,   72,   72,
        0,   72,   72,   76,   76,    0,   76,    0,   76,   76,
       76,   76,   76,   76,   81,   81,   81,    0,   81,   81,
       85,   85,    0,   85,    0,   85,   85,   85,   85,   85,
       85,   90,   90,   90,    0,   90,   90,   94,   94,    0,
       94,    0,   94,   94,   94,   94,   94,   94,   99,   99,

       99,    0,   99,   99,  103,  103,    0,  103,    0,  103,
      103,  103,  103,  103,  103,  108,  108,  108,    0,  108,
      108,  112,  112,    0,  112,    0,  112,  112,  112,  112,
      112,  112,  128,  128,  128,  128,  128,  129,  129,  129,
      129,  129,  130,    0,    0,  130,  131,  131,  132,  132,
      132,    0,  132,  133,  133,    0,    0,  133,  134,  134,
        0,    0,  134,  135,  135,    0,    0,  135,  136,  136,
        0,    0,  136,  137,  137,    0,    0,  137,  138,  138,
        0,    0,  138,  139,  139,    0,    0,  139,  140,  140,
        0,    0,  140,  141,  141,    0,    0,  141,  142,  142,

        0,    0,  142,  143,  143,    0,    0,  143,  144,  144,
        0,    0,  144,  145,  145,    0,    0,  145,  146,  146,
        0,    0,  146,  147,  147,    0,    0,  147,  148,  148,
        0,    0,  148,  149,  149,    0,    0,  149,  150,  150,
        0,    0,  150,  127,  127,  127,  127,  127,  127,  127,
      127,  127,  127,  127,  127
    } ;

extern int phylips_flex_debug;
int phylips_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
static int yy_looking_for_trail_begin = 0;
static int yy_full_lp;
static int *yy_full_state;
#define YY_TRAILING_MASK 0x2000
#define YY_TRAILING_HEAD_MASK 0x4000
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up phylipstext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
(yy_lp) = (yy_full_lp); /* restore orig. accepting pos. */ \
(yy_state_ptr) = (yy_full_state); /* restore orig. state */ \
yy_current_state = *(yy_state_ptr); /* restore curr. state */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *phylipstext;
#line 1 "align/phylipsl.l"
/* phylipsl.l - PHYLIPS alignment lexer */
#line 4 "align/phylipsl.l"
#ifdef HAVE_CONFIG_H
# include <config.h>
#endif

#ifdef STDC_HEADERS
# include <stdlib.h>
# include <string.h>
#endif
#include <ctype.h>

#include "align/phylipsy.h"

static void clean_spc(char *str);
#define YY_NO_INPUT 1

#line 646 "align/phylipsl.c"

#define INITIAL 0
#define HEAD 1
#define SEQS 2

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int phylipslex_destroy (void );

int phylipsget_debug (void );

void phylipsset_debug (int debug_flag  );

YY_EXTRA_TYPE phylipsget_extra (void );

void phylipsset_extra (YY_EXTRA_TYPE user_defined  );

FILE *phylipsget_in (void );

void phylipsset_in  (FILE * _in_str  );

FILE *phylipsget_out (void );

void phylipsset_out  (FILE * _out_str  );

int phylipsget_leng (void );

char *phylipsget_text (void );

int phylipsget_lineno (void );

void phylipsset_lineno (int _line_number  );

YYSTYPE * phylipsget_lval (void );

void phylipsset_lval (YYSTYPE * yylval_param  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int phylipswrap (void );
#else
extern int phylipswrap (void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO fwrite( phylipstext, phylipsleng, 1, phylipsout )
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( phylipsin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( phylipsin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, phylipsin))==0 && ferror(phylipsin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(phylipsin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int phylipslex \
               (YYSTYPE * yylval_param );

#define YY_DECL int phylipslex \
               (YYSTYPE * yylval_param )
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after phylipstext and phylipsleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	if ( phylipsleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(phylipstext[phylipsleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	register yy_state_type yy_current_state;
	register char *yy_cp, *yy_bp;
	register int yy_act;
    
        YYSTYPE * yylval;
    
#line 40 "align/phylipsl.l"


#line 846 "align/phylipsl.c"

    yylval = yylval_param;

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)phylipsalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in phylipslex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! phylipsin )
			phylipsin = stdin;

		if ( ! phylipsout )
			phylipsout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			phylipsensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				phylips_create_buffer(phylipsin,YY_BUF_SIZE );
		}

		phylips_load_buffer_state( );
		}

	while (/*CONSTCOND*/ 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of phylipstext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			register YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)];
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 128 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_current_state != 127 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];
find_rule: /* we branch to this label when backing up */
		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
				if ( yy_act & YY_TRAILING_HEAD_MASK ||
				     (yy_looking_for_trail_begin) )
					{
					if ( yy_act == (yy_looking_for_trail_begin) )
						{
						(yy_looking_for_trail_begin) = 0;
						yy_act &= ~YY_TRAILING_HEAD_MASK;
						break;
						}
					}
				else if ( yy_act & YY_TRAILING_MASK )
					{
					(yy_looking_for_trail_begin) = yy_act & ~YY_TRAILING_MASK;
					(yy_looking_for_trail_begin) |= YY_TRAILING_HEAD_MASK;
					}
				else
					{
					(yy_full_match) = yy_cp;
					(yy_full_state) = (yy_state_ptr);
					(yy_full_lp) = (yy_lp);
					break;
					}
				++(yy_lp);
				goto find_rule;
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 42 "align/phylipsl.l"
; /* Empty lines ignored */
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 44 "align/phylipsl.l"
{ BEGIN HEAD; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 45 "align/phylipsl.l"
{ return INT; }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 46 "align/phylipsl.l"
{ return SPC; }
	YY_BREAK
case 5:
/* rule 5 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up phylipstext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up phylipstext again */
YY_RULE_SETUP
#line 47 "align/phylipsl.l"
; /* Ignore trailing spaces */
	YY_BREAK
case 6:
/* rule 6 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up phylipstext */
(yy_c_buf_p) = yy_cp -= 1;
YY_DO_BEFORE_ACTION; /* set up phylipstext again */
YY_RULE_SETUP
#line 48 "align/phylipsl.l"
; /* Extra stuff ignored */
	YY_BREAK
case 7:
/* rule 7 can match eol */
YY_RULE_SETUP
#line 49 "align/phylipsl.l"
{ BEGIN SEQS; return EOL; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 50 "align/phylipsl.l"
{ return ERR; }
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 52 "align/phylipsl.l"
; /* Leading spaces ignored */
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 53 "align/phylipsl.l"
{ yylval->str = strdup(phylipstext); clean_spc(yylval->str);
                 BEGIN SEQS; return NAM; }
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 55 "align/phylipsl.l"
{ yylval->str = strdup(phylipstext); return BAS; }
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 56 "align/phylipsl.l"
; /* Sequence spaces ignored */
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 57 "align/phylipsl.l"
; /* Empty lines ignored */
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 58 "align/phylipsl.l"
{ return ERR; } /* Not allowed */
	YY_BREAK
case 15:
/* rule 15 can match eol */
*yy_cp = (yy_hold_char); /* undo effects of setting up phylipstext */
(yy_c_buf_p) = yy_cp = yy_bp + 1;
YY_DO_BEFORE_ACTION; /* set up phylipstext again */
YY_RULE_SETUP
#line 59 "align/phylipsl.l"
{ return EOL; }
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 60 "align/phylipsl.l"
{ return EOL; }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 61 "align/phylipsl.l"
{ BEGIN INITIAL; return EOL; }
	YY_BREAK
case YY_STATE_EOF(SEQS):
#line 62 "align/phylipsl.l"
{ BEGIN INITIAL; return EOL; }
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 63 "align/phylipsl.l"
{ return ERR; }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(HEAD):
#line 65 "align/phylipsl.l"
{ return END; }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 66 "align/phylipsl.l"
{ return ERR; }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 67 "align/phylipsl.l"
{ return ERR; }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 69 "align/phylipsl.l"
YY_FATAL_ERROR( "flex scanner jammed" );
	YY_BREAK
#line 1095 "align/phylipsl.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed phylipsin at a new source and called
			 * phylipslex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = phylipsin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( phylipswrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * phylipstext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of phylipslex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	register char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	register char *source = (yytext_ptr);
	register int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), (size_t) num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			phylipsrestart(phylipsin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) phylipsrealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	register yy_state_type yy_current_state;
	register char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		register YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 128 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	register int yy_is_jam;
    
	register YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 128 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 127);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

	return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					phylipsrestart(phylipsin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( phylipswrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve phylipstext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void phylipsrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        phylipsensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            phylips_create_buffer(phylipsin,YY_BUF_SIZE );
	}

	phylips_init_buffer(YY_CURRENT_BUFFER,input_file );
	phylips_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void phylips_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		phylipspop_buffer_state();
	 *		phylipspush_buffer_state(new_buffer);
     */
	phylipsensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	phylips_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (phylipswrap()) processing, but the only time this flag
	 * is looked at is after phylipswrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void phylips_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	phylipsin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE phylips_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) phylipsalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in phylips_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) phylipsalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in phylips_create_buffer()" );

	b->yy_is_our_buffer = 1;

	phylips_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with phylips_create_buffer()
 * 
 */
    void phylips_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		phylipsfree((void *) b->yy_ch_buf  );

	phylipsfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a phylipsrestart() or at EOF.
 */
    static void phylips_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	phylips_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then phylips_init_buffer was _probably_
     * called from phylipsrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void phylips_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		phylips_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void phylipspush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	phylipsensure_buffer_stack();

	/* This block is copied from phylips_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from phylips_switch_to_buffer. */
	phylips_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void phylipspop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	phylips_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		phylips_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void phylipsensure_buffer_stack (void)
{
	int num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)phylipsalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in phylipsensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)phylipsrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in phylipsensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE phylips_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) phylipsalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in phylips_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	phylips_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to phylipslex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       phylips_scan_bytes() instead.
 */
YY_BUFFER_STATE phylips_scan_string (yyconst char * yystr )
{
    
	return phylips_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to phylipslex() will
 * scan from a @e copy of @a bytes.
 * @param bytes the byte buffer to scan
 * @param len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE phylips_scan_bytes  (yyconst char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) phylipsalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in phylips_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = phylips_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in phylips_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up phylipstext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		phylipstext[phylipsleng] = (yy_hold_char); \
		(yy_c_buf_p) = phylipstext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		phylipsleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int phylipsget_lineno  (void)
{
        
    return phylipslineno;
}

/** Get the input stream.
 * 
 */
FILE *phylipsget_in  (void)
{
        return phylipsin;
}

/** Get the output stream.
 * 
 */
FILE *phylipsget_out  (void)
{
        return phylipsout;
}

/** Get the length of the current token.
 * 
 */
int phylipsget_leng  (void)
{
        return phylipsleng;
}

/** Get the current token.
 * 
 */

char *phylipsget_text  (void)
{
        return phylipstext;
}

/** Set the current line number.
 * @param _line_number
 * 
 */
void phylipsset_lineno (int  _line_number )
{
    
    phylipslineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see phylips_switch_to_buffer
 */
void phylipsset_in (FILE *  _in_str )
{
        phylipsin = _in_str ;
}

void phylipsset_out (FILE *  _out_str )
{
        phylipsout = _out_str ;
}

int phylipsget_debug  (void)
{
        return phylips_flex_debug;
}

void phylipsset_debug (int  _bdebug )
{
        phylips_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from phylipslex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    phylipsin = stdin;
    phylipsout = stdout;
#else
    phylipsin = (FILE *) 0;
    phylipsout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * phylipslex_init()
     */
    return 0;
}

/* phylipslex_destroy is for both reentrant and non-reentrant scanners. */
int phylipslex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		phylips_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		phylipspop_buffer_state();
	}

	/* Destroy the stack itself. */
	phylipsfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    phylipsfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * phylipslex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	register int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	register int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *phylipsalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *phylipsrealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void phylipsfree (void * ptr )
{
	free( (char *) ptr );	/* see phylipsrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 69 "align/phylipsl.l"




/* Clean trailing spaces ... */
static void clean_spc(char *str) {
  char *p;

  p = str;
  while (*p) { p++; }
  p--;
  while (p >= str && isspace((unsigned char)*p)) {
    *p = '\0'; p--; }

  return; }

